@@ -38,8 +38,8 @@ printGeneral <- function(censoring,
     df.endpoint <- data.frame(matrix(NA, nrow = D, ncol = 6,
                                      dimnames = list(NULL, name.col)
                                      ))
-    df.endpoint[,1] <- paste0("     |",1:D)
-    names(df.endpoint)[1] <- "     |priority"
+    df.endpoint[,1] <- paste0("      ",1:D)
+    names(df.endpoint)[1] <- "      priority"
     df.endpoint$endpoint <- endpoint
     df.endpoint$type <- c("binary","continuous","time to event")[type]
     df.endpoint$operator <- c("lower is favorable","higher is favorable")[1 + (operator == ">0")]
@@ -53,7 +53,6 @@ printGeneral <- function(censoring,
             df.endpoint$threshold <- NULL
         }
     }
-    df.endpoint <- cbind(df.endpoint, `|` = "|")
     
     ## threshold
     if(any(type==3)){
@@ -73,28 +72,30 @@ printGeneral <- function(censoring,
     }
     
     ## ** Display
-    cat("Settings (punctual estimation) \n")
+    cat("Settings (point estimation) \n")
     cat("   > treatment groups: Control = ",level.treatment[1]," and Treatment = ",level.treatment[2],"\n", sep = "")
     cat("   > ",D," endpoint",if(D>1){"s"},": \n", sep = "")
     print(df.endpoint, row.names = FALSE, quote = FALSE, right = FALSE)
     if(n.strata>1){
-        cat("   > ", n.strata, " strata with levels ", paste(level.strata,collapse = " "), "\n", sep = "")
+        txt.variable <- switch(as.character(length(strata)),
+                               "0" = " variable",
+                               "variables")        
+        cat("   > ", n.strata, " strata with levels: ",paste(level.strata, collapse = " ") , "\n", sep = "")
+        cat("                ",txt.variable,": ",paste(strata, collapse = " ")," \n", sep = "")
     }
-    cat("   > management of neutral pairs : ")
+    cat("   > management of neutral pairs: ")
     if(neutral.as.uninf){
         cat("re-analyzed using endpoints of lower priority (if any) \n")
     }else{
         cat("ignore endpoints of lower priority \n")
     }
     if(any(type==3)){
-        cat("   > management of censored survival pairs : ")
+        cat("   > management of censored survival pairs: ")
         switch(as.character(method.tte),
                "0" = cat("uninformative pairs \n"),
-               "1" = cat("imputation using Kaplan Meier \n"),
-               "2" = cat("imputation using Kaplan Meier stratified by treatment group \n"),
-               "3" = cat("imputation using Kaplan Meier stratified by treatment group \n")
+               "1" = cat("use Kaplan Meier survival curves to compute the score \n")
                ) 
-        if (method.tte %in% c("1","2","3")) {
+        if (method.tte %in% c("1","2","3") && D.TTE>1) {
             
             cat("   > weights of the pairs relatively to the enpoints: \n")
             print(Wscheme)
