@@ -15,62 +15,64 @@ using namespace Rcpp ;
 using namespace std ;
 using namespace arma ;
 
-// * Documentation BuyseTest_cpp
-//' @name BuyseTest_cpp
-//' @aliases BuyseTest_Gehan_cpp BuyseTest_PetoEfronPeron_cpp
+// * Documentation GPC_cpp
 //' @title C++ function performing the pairwise comparison over several endpoints. 
+//' @description \code{GPC_cpp} call for each endpoint and each strata the pairwise comparison function suited to the type of endpoint and store the resuts. 
+//' @name GPC_cpp
 //' 
-//' @description \code{BuyseTest_Gehan_cpp} and \code{BuyseTest_PetoEfron_cpp} functions calls for each endpoint and each strata the pairwise comparison function suited to the type of endpoint and store the resuts. 
-//' 
-//' @param Treatment A matrix containing the values of each endpoint (in columns) for the treatment group (in rows). \emph{const arma::mat&}.
 //' @param Control A matrix containing the values of each endpoint (in columns) for the control group (in rows). \emph{const arma::mat&}.
+//' @param Treatment A matrix containing the values of each endpoint (in columns) for the treatment group (in rows). \emph{const arma::mat&}.
 //' @param threshold Store the thresholds associated to each endpoint. \emph{const NumericVector&}. Must have length D. The threshold is ignored for binary endpoints. Must have D columns.
 //' @param survEndpoint Does each endpoint is a time to event. \emph{const LogicalVector&}. Must have length D.
-//' @param delta_Treatment A matrix containing in the type of event (0 censoring, 1 event) for each TTE endpoint (in columns) and treatment observations (in rows). \emph{const arma::mat&} containing binary integers. Must have n_TTE columns. Ignored if n_TTE equals 0.
 //' @param delta_Control A matrix containing the nature of observations in the control group (in rows) (0 censoring, 1 event) for each TTE endpoint (in columns) . \emph{const arma::mat&} containing binary integers. Must have n_TTE columns. Ignored if n_TTE equals 0.
+//' @param delta_Treatment A matrix containing in the type of event (0 censoring, 1 event) for each TTE endpoint (in columns) and treatment observations (in rows). \emph{const arma::mat&} containing binary integers. Must have n_TTE columns. Ignored if n_TTE equals 0.
 //' @param D The number of endpoints. Strictly positive \emph{const int}.
-//' @param returnIndex Should the indexes of the neutral or uninformative pairs be returned. \emph{const bool}.
-//' @param strataT A list containing the indexes of treatment observations belonging for each strata. \emph{List&} of vector containing positive integers. 
 //' @param strataC A list containing the indexes of control observations belonging for each strata. \emph{List&}  of vector containing positive integers. 
+//' @param strataT A list containing the indexes of treatment observations belonging for each strata. \emph{List&} of vector containing positive integers. 
 //' @param n_strata The number of strata . Strictly positive \emph{const int}.
 //' @param n_TTE The number of time-to-event endpoints. Positive \emph{const int}.
 //' @param Wscheme The matrix describing the weighting strategy. For each endpoint (except the first) in column, weights of each pair are initialized at 1 and multiplied by the weight of the endpoints in rows where there is a 1. \emph{const arma::mat&}. Must have n_TTE lines and D-1 columns.
 //' @param index_survivalM1 The position, among all the survival endpoints, of the last same endpoint (computed with a different threshold). If it is the first time that the TTE endpoint is used it is set to -1. \emph{const IntegerVector}. Must have length n_TTE.
 //' @param threshold_TTEM1 The previous latest threshold of each TTE endpoint. When it is the first time that the TTE endpoint is used it is set to -1. \emph{const NumericVector}. Must have length n_TTE.
-//' @param list_survivalT A list of matrix containing the survival estimates (-threshold, 0, +threshold ...) for each event of the treatment group (in rows). \emph{List&}. Must have length n_TTE. Each matrix must have 3 (if method is Peto, only one survival function is computed) or 11 (if method is Efron or Peron, two survival functions are computed) columns. Ignored if method is Gehan.
-//' @param list_survivalC A list of matrix containing the survival estimates (-threshold, 0, +threshold ...) for each event of the control group (in rows). \emph{List&}. Must have length n_TTE. Each matrix must have 3 (if method is Peto) or 11 (if method is Efron or Peron) columns. Ignored if method is Gehan.
-//' @param correctionTTE Should the uninformative weight be re-distributed to favorable and unfavorable?
-//' @param methodTTE The type of method used to compare censored pairs (1 Peto, 2 Efron, 3 Peron).
+//' @param list_survTimeC A list of matrix containing the survival estimates (-threshold, 0, +threshold ...) for each event of the control group (in rows). \emph{List&}.
+//' @param list_survTimeT A list of matrix containing the survival estimates (-threshold, 0, +threshold ...) for each event of the treatment group (in rows). \emph{List&}. 
+//' @param list_survJumpC A list of matrix containing the survival estimates and survival jumps when the survival for the control arm jumps. \emph{List&}.
+//' @param list_survJumpT A list of matrix containing the survival estimates and survival jumps when the survival for the treatment arm jumps. \emph{List&}. 
+//' @param list_lastSurv A list of matrix containing the last survival estimate in each strata (rows) and treatment group (columns). \emph{List&}. 
+//' @param correctionUninf Should the uninformative weight be re-distributed to favorable and unfavorable?
+//' @param methodTTE The type of method used to compare censored pairs (0 Gehan 1 Peron).
 //' @param neutralAsUninf Should paired classified as neutral be re-analyzed using endpoints of lower priority?  \emph{logical}.
-//' @param keepComparison Should the result of each pairwise comparison be kept? \emph{logical}.
+//' @param keepScore Should the result of each pairwise comparison be kept? \emph{logical}.
 //' @keywords function Cpp BuyseTest
 
-// * Function BuyseTest_cpp
-//' @name BuyseTest_cpp
+// * Function GPC_cpp
+//' @name GPC_cpp
 //' @export
 // [[Rcpp::export]]
-List GPC_cpp(const arma::mat& Treatment,
-	     const arma::mat& Control,
+List GPC_cpp(const arma::mat& Control,
+	     const arma::mat& Treatment,
 	     const NumericVector& threshold,
 	     const LogicalVector& survEndpoint,
-	     const arma::mat& delta_Treatment,
 	     const arma::mat& delta_Control,
-             const int D,
-	     const bool returnIndex,
-	     const std::vector< arma::uvec >& strataT,
+             const arma::mat& delta_Treatment,
+	     const int D,
 	     const std::vector< arma::uvec >& strataC,
+	     const std::vector< arma::uvec >& strataT,
 	     const int n_strata,
 	     const int n_TTE, 
              const arma::mat& Wscheme,
 	     const IntegerVector index_survivalM1,
 	     const NumericVector threshold_TTEM1, 
-             const std::vector< arma::mat >& list_survivalT,
-	     const std::vector< arma::mat >& list_survivalC,
+	     const std::vector< std::vector< arma::mat > >& list_survTimeC,
+             const std::vector< std::vector< arma::mat > >& list_survTimeT,
+             const std::vector< std::vector< arma::mat > >& list_survJumpC,
+	     const std::vector< std::vector< arma::mat > >& list_survJumpT,
+	     const std::vector< arma::mat >& list_lastSurv,
 	     const int methodTTE,
-	     const bool correctionTTE,
+	     const int correctionUninf,
 	     const bool neutralAsUninf,
-	     const bool keepComparison){
-  
+	     const bool keepScore){
+
   // WARNING : strataT and strataC should be passed as const argument but it leads to an error in the conversion to arma::uvec.
   // NOTE : each pair has an associated weight initialized at 1. The number of pairs and the total weight are two different things.
   // (ex : 3 pairs with weights 0.5 0.75 0.5 have total weight 1.75). 
@@ -85,12 +87,7 @@ List GPC_cpp(const arma::mat& Treatment,
   arma::mat Mcount_unfavorable(n_strata,D,fill::zeros); // store the total weight of unfavorable pairs by outcome for each strata
   arma::mat Mcount_neutral(n_strata,D,fill::zeros); // store the total weight of neutral pairs by outcome for each strata
   arma::mat Mcount_uninf(n_strata,D,fill::zeros); // store the total weight of uninf pairs by outcome for each strata
-  double n_pairs=0; // number of pairs sumed over the strats
-  
-  vector<int> index_neutralT(0) ; // index of the neutral pairs of the treatment arm
-  vector<int> index_neutralC(0) ; // index of the neutral pairs of the control arm
-  vector<int> index_uninfT(0) ; // index of the uninformative pairs of the treatment arm
-  vector<int> index_uninfC(0) ; // index of the uninformative pairs of the control arm
+  vector<double> n_pairs(n_strata); // number of pairs sumed over the strats
   
   // *** for a given stata [input]
   arma::uvec index_strataT; // position of a patients belonging to a given strata in the treatment arm
@@ -99,8 +96,6 @@ List GPC_cpp(const arma::mat& Treatment,
   arma::mat ControlK; // Endpoint(s) for controls restricted to stata k
   arma::mat delta_TreatmentK ; // statut for TTE endpoints for treated restricted to strata k
   arma::mat delta_ControlK ; // statut for TTE endpoints for controls restricted to stata k
-  arma::mat matKMT_K ; // KM estimates for treated restricted to stata k
-  arma::mat matKMC_K ; // KM estimates for controls restricted to stata k
   
   int iter_d; // the index of the endpoints
   int iter_dTTE; // number of time to event endpoints that have been used
@@ -112,7 +107,7 @@ List GPC_cpp(const arma::mat& Treatment,
   vector<int> iIndex_uninfT; // index of the uninformative pairs of the treatment arm
   vector<int> iIndex_uninfC; // index of the uninformative pairs of the control arm
   vector<double> iw; // weights of the neutral / uninformative pairs
-  vector<int> iIndex_w; // index of the pair number of the neutral / uninformative pairs
+  vector<int> iIndex_w; // index of the pairs number of the neutral / uninformative pairs
   
   int size_neutral; // number of neutral pairs (temporary)
   int size_uninf; // number of uninformative pairs (temporary)
@@ -122,14 +117,16 @@ List GPC_cpp(const arma::mat& Treatment,
   arma::mat Wpairs_sauve; // the previous update of Wpairs
   arma::vec w; // current weigths
   double iThreshold_M1; // threshold of the previous survival endpoint
-  arma::mat iMatKMT_KM1 ; // KM estimates for treated restricted to stata k (previous endpoint, necessary for Peto/Efron/Peron)
-  arma::mat iMatKMC_KM1 ; // KM estimates for controls restricted to stata k (previous endpoint, necessary for Peto/Efron/Peron)
-  
+  arma::mat iSurvTimeC_M1;
+  arma::mat iSurvTimeT_M1;
+  arma::mat iSurvJumpC_M1;
+  arma::mat iSurvJumpT_M1;
+		
   vector<int> tempo_index;  // temporary index vector used to convert the index SEXP into vector<int>
 
   // *** keep track of each comparison
-  vector<arma::mat> lsComp(D);
-  arma::mat iComparison;
+  vector<arma::mat> lsScore(D);
+  arma::mat iScore;
   arma::mat iMat;
   int iNpairs;
       
@@ -152,78 +149,82 @@ List GPC_cpp(const arma::mat& Treatment,
     }
     
     // *** first endpoint
+    // Rcout << "** endpoint 0 **" << endl;
     iIndex_neutralT.resize(0); iIndex_neutralC.resize(0); iIndex_uninfT.resize(0); iIndex_uninfC.resize(0); iw.resize(0);
     
     if(survEndpoint[0]){ // time to event endpoint
       
       if(methodTTE == 0){
-	iComparison = calcAllPairs_TTEgehan(TreatmentK.col(0), ControlK.col(0), threshold[0],
-					    delta_TreatmentK.col(0), delta_ControlK.col(0),
-					    correctionTTE,
-					    Mcount_favorable(iter_strata,0), Mcount_unfavorable(iter_strata,0), Mcount_neutral(iter_strata,0), Mcount_uninf(iter_strata,0), 
-					    iIndex_neutralT, iIndex_neutralC, iIndex_uninfT, iIndex_uninfC, 
-					    iw, keepComparison); 
+	iScore = calcAllPairs_TTEgehan(ControlK.col(0), TreatmentK.col(0), threshold[0],
+								   delta_ControlK.col(0), delta_TreatmentK.col(0), 
+								   correctionUninf,
+								   Mcount_favorable(iter_strata,0), Mcount_unfavorable(iter_strata,0), Mcount_neutral(iter_strata,0), Mcount_uninf(iter_strata,0), 
+								   iIndex_neutralC, iIndex_neutralT, iIndex_uninfC, iIndex_uninfT, 
+								   iw, neutralAsUninf, keepScore); 
       }else{
-	matKMT_K = list_survivalT[0].rows(index_strataT);
-	matKMC_K = list_survivalC[0].rows(index_strataC);
 
-	iComparison = calcAllPairs_TTEperon(TreatmentK.col(0), ControlK.col(0), threshold[0],
-					    delta_TreatmentK.col(0), delta_ControlK.col(0), matKMT_K, matKMC_K,
-					    methodTTE, correctionTTE,
-					    Mcount_favorable(iter_strata,0), Mcount_unfavorable(iter_strata,0), Mcount_neutral(iter_strata,0), Mcount_uninf(iter_strata,0), 
-					    iIndex_neutralT, iIndex_neutralC, iIndex_uninfT, iIndex_uninfC, 
-					    iw, keepComparison);
+		iScore = calcAllPairs_TTEperon(ControlK.col(0), TreatmentK.col(0), threshold[0],
+									   delta_ControlK.col(0), delta_TreatmentK.col(0),
+									   list_survTimeC[0][iter_strata], list_survTimeT[0][iter_strata], list_survJumpC[0][iter_strata], list_survJumpT[0][iter_strata],
+									   list_lastSurv[0](iter_strata,0), list_lastSurv[0](iter_strata,1), 
+									   correctionUninf,
+									   Mcount_favorable(iter_strata,0), Mcount_unfavorable(iter_strata,0), Mcount_neutral(iter_strata,0), Mcount_uninf(iter_strata,0), 
+									   iIndex_neutralC, iIndex_neutralT, iIndex_uninfC, iIndex_uninfT, 
+									   iw, neutralAsUninf, keepScore);
       }
       iter_dTTE++; // increment the number of time to event endpoints that have been used
       
     }else { // binary or continuous endpoint
       
-      iComparison = calcAllPairs_Continuous(TreatmentK.col(0),ControlK.col(0),threshold[0],
-					    Mcount_favorable(iter_strata,0), Mcount_unfavorable(iter_strata,0), Mcount_neutral(iter_strata,0), Mcount_uninf(iter_strata,0), 
-					    iIndex_neutralT, iIndex_neutralC, iIndex_uninfT, iIndex_uninfC,
-					    keepComparison);
+      iScore = calcAllPairs_Continuous(ControlK.col(0), TreatmentK.col(0), threshold[0],
+									   correctionUninf,
+									   Mcount_favorable(iter_strata,0), Mcount_unfavorable(iter_strata,0), Mcount_neutral(iter_strata,0), Mcount_uninf(iter_strata,0), 
+									   iIndex_neutralC, iIndex_neutralT, iIndex_uninfC, iIndex_uninfT, 
+									   neutralAsUninf, keepScore);
       
     }
-    
+
     // **** add to the total number of pairs the number of pairs founded for this endpoint
-    n_pairs += Mcount_favorable(iter_strata,0) + Mcount_unfavorable(iter_strata,0) + Mcount_neutral(iter_strata,0) + Mcount_uninf(iter_strata,0);
+    n_pairs[iter_strata] = Mcount_favorable(iter_strata,0) + Mcount_unfavorable(iter_strata,0) + Mcount_neutral(iter_strata,0) + Mcount_uninf(iter_strata,0);
     size_neutral = iIndex_neutralT.size(); // update the number of neutral pairs
     size_uninf = iIndex_uninfT.size(); // update the number of uninformative pairs
     
-    // **** update Wpairs
+	  // Rcout << "update Wpairs" << endl;
+	  // **** update Wpairs
     if(D>1){ // if there is more than one endpoint
       Wpairs.resize(size_neutral+size_uninf,1); // temporary matrix containing the weigth of each remaining pair for each outcome
       Wpairs.fill(1.0);
       w.resize(size_neutral+size_uninf); // temporary vector containing the weight of each remaining pair to be used for the next outcome
       w.fill(1.0);
 	    
-      if((methodTTE>0 || correctionTTE) && iter_dTTE>0){ // update the weights for the neutral pairs in Wpairs and w	
-	for(int iter_neutral=0 ; iter_neutral<size_neutral ; iter_neutral++){
+      if((methodTTE>0 || correctionUninf>0) && iter_dTTE>0){ // update the weights for the neutral pairs in Wpairs and w	
+		for(int iter_neutral=0 ; iter_neutral<size_neutral ; iter_neutral++){
           Wpairs(iter_neutral,0) = iw[iter_neutral];
           if(Wscheme(0,0)==1){w(iter_neutral) = iw[iter_neutral];}
         }
-        for(int iter_uninf=0 ; iter_uninf<size_uninf ; iter_uninf++){ 
+        for(int iter_uninf=0 ; iter_uninf<size_uninf ; iter_uninf++){
           Wpairs(size_neutral+iter_uninf,0) = iw[size_neutral + iter_uninf];
           if(Wscheme(0,0)==1){w(size_neutral+iter_uninf) = iw[size_neutral + iter_uninf];}
         }
       }
     }
-    
-    // **** update all Comparisons
-    if(keepComparison){
-      iNpairs = iComparison.n_rows;
+
+	// Rcout << "update Scores" << endl;
+    // **** update all Scores
+    if(keepScore){
+      iNpairs = iScore.n_rows;
       iMat.resize(iNpairs,3);
       // add original index
       for(int iPair=0 ; iPair < iNpairs ; iPair ++){
-	iMat.row(iPair) = rowvec({(double)iter_strata,
-	      (double)index_strataT(iComparison(iPair,0)),
-	      (double)index_strataC(iComparison(iPair,1))});
+		iMat.row(iPair) = rowvec({(double)iter_strata,
+			  (double)index_strataC(iScore(iPair,0)),
+			  (double)index_strataT(iScore(iPair,1))});
       }
       // merge with current table and store
       if(iter_strata==0){
-	lsComp[0] = arma::join_rows(iMat,iComparison);
+		lsScore[0] = arma::join_rows(iMat,iScore);
       }else{
-        lsComp[0] = arma::join_cols(lsComp[0],arma::join_rows(iMat,iComparison));
+        lsScore[0] = arma::join_cols(lsScore[0],arma::join_rows(iMat,iScore));
       }
     }
 
@@ -232,64 +233,76 @@ List GPC_cpp(const arma::mat& Treatment,
 
       // while there are remaining endpoints and remaining neutral or uniformative pairs
       iter_d++; // increment the index of the endpoints
+      // Rcout << "** endpoint " << iter_d << " **" << endl;
       Wpairs_sauve = Wpairs; // save the current Wpairs
-      if(neutralAsUninf==false){size_neutral = 0;} // stop the analysis of the neutral pairs
       iw.resize(0); iIndex_w.resize(0);
       
       if(survEndpoint[iter_d]){ // time to event endpoint
 
-	if(methodTTE==0){
-	  iComparison = calcSubsetPairs_TTEgehan(TreatmentK.col(iter_d),ControlK.col(iter_d),threshold[iter_d],
-						 delta_TreatmentK.col(iter_dTTE),delta_ControlK.col(iter_dTTE),
-						 correctionTTE,
-						 Mcount_favorable(iter_strata,iter_d), Mcount_unfavorable(iter_strata,iter_d), Mcount_neutral(iter_strata,iter_d), Mcount_uninf(iter_strata,iter_d), 
-						 iIndex_neutralT, iIndex_neutralC, size_neutral,
-						 iIndex_uninfT, iIndex_uninfC, size_uninf,
-						 w, iw, iIndex_w,
-						 keepComparison);
-	}else{
-          matKMT_K = list_survivalT[iter_dTTE].rows(index_strataT);
-          matKMC_K = list_survivalC[iter_dTTE].rows(index_strataC);
+		if(methodTTE==0){
+		  iScore = calcSubsetPairs_TTEgehan(ControlK.col(iter_d), TreatmentK.col(iter_d), threshold[iter_d],
+											delta_ControlK.col(iter_dTTE), delta_TreatmentK.col(iter_dTTE),
+											correctionUninf,
+											Mcount_favorable(iter_strata,iter_d), Mcount_unfavorable(iter_strata,iter_d),
+											Mcount_neutral(iter_strata,iter_d), Mcount_uninf(iter_strata,iter_d), 
+											iIndex_neutralC, iIndex_neutralT, size_neutral,
+											iIndex_uninfC, iIndex_uninfT, size_uninf,
+											w, iw, iIndex_w, // Wpairs wNeutral index_wNeutral
+											neutralAsUninf, keepScore);
+		}else{
         
-	  if(threshold_TTEM1[iter_dTTE]<0){ // first time the endpoint is used [no threshold-1]
-	    iThreshold_M1 = -1;
-	    iMatKMT_KM1 = arma::mat(1,1) ;
-	    iMatKMC_KM1 = arma::mat(1,1) ;
-	  }else{ // following times
-	    iThreshold_M1 = threshold_TTEM1[iter_dTTE];
-	    iMatKMT_KM1 = list_survivalT[index_survivalM1[iter_dTTE]].rows(index_strataT) ;
-	    iMatKMC_KM1 = list_survivalC[index_survivalM1[iter_dTTE]].rows(index_strataC) ;
-	  }
-	
-          iComparison = calcSubsetPairs_TTEperon(TreatmentK.col(iter_d),ControlK.col(iter_d),threshold[iter_d],
-						 delta_TreatmentK.col(iter_dTTE),delta_ControlK.col(iter_dTTE), matKMT_K, matKMC_K, methodTTE, correctionTTE,
-						 Mcount_favorable(iter_strata,iter_d), Mcount_unfavorable(iter_strata,iter_d), Mcount_neutral(iter_strata,iter_d), Mcount_uninf(iter_strata,iter_d), 
-						 iIndex_neutralT, iIndex_neutralC, size_neutral,
-						 iIndex_uninfT, iIndex_uninfC, size_uninf,
-						 w, iThreshold_M1, iMatKMT_KM1, iMatKMC_KM1,
-						 iw, iIndex_w,
-						 keepComparison);
-	}
+		  if(threshold_TTEM1[iter_dTTE]<0){ // first time the endpoint is used [no threshold-1]
+			iThreshold_M1 = -1;
+			iSurvTimeC_M1 = arma::mat(0,0);
+			iSurvTimeT_M1 = arma::mat(0,0);
+			iSurvJumpC_M1 = arma::mat(0,0);
+			iSurvJumpT_M1 = arma::mat(0,0);
 
-	iter_dTTE++; // increment the number of time to event endpoints that have been used
+		  }else{ // following times
+			iThreshold_M1 = threshold_TTEM1[iter_dTTE];
+			iSurvTimeC_M1 = list_survTimeC[index_survivalM1[iter_dTTE]][iter_strata];
+			iSurvTimeT_M1 = list_survTimeT[index_survivalM1[iter_dTTE]][iter_strata];
+			iSurvJumpC_M1 = list_survJumpC[index_survivalM1[iter_dTTE]][iter_strata];
+			iSurvJumpT_M1 = list_survJumpT[index_survivalM1[iter_dTTE]][iter_strata];
+		  }
+	
+          iScore = calcSubsetPairs_TTEperon(ControlK.col(iter_d), TreatmentK.col(iter_d), threshold[iter_d],
+											delta_ControlK.col(iter_dTTE), delta_TreatmentK.col(iter_dTTE),
+											list_survTimeC[iter_dTTE][iter_strata], list_survTimeT[iter_dTTE][iter_strata],
+											list_survJumpC[iter_dTTE][iter_strata], list_survJumpT[iter_dTTE][iter_strata],
+											list_lastSurv[iter_dTTE](iter_strata,0), list_lastSurv[iter_dTTE](iter_strata,1), 
+											correctionUninf,
+											Mcount_favorable(iter_strata,iter_d), Mcount_unfavorable(iter_strata,iter_d),
+											Mcount_neutral(iter_strata,iter_d), Mcount_uninf(iter_strata,iter_d), 
+											iIndex_neutralC, iIndex_neutralT, size_neutral,
+											iIndex_uninfC, iIndex_uninfT, size_uninf,
+											w, iThreshold_M1,
+											iSurvTimeC_M1, iSurvTimeT_M1, iSurvJumpC_M1, iSurvJumpT_M1,
+											iw, iIndex_w,
+											neutralAsUninf, keepScore);
+		}
+
+		iter_dTTE++; // increment the number of time to event endpoints that have been used
 	
       }else{ // binary or continuous endpoint
 	
-        iComparison = calcSubsetPairs_Continuous(TreatmentK.col(iter_d),ControlK.col(iter_d),threshold[iter_d],
-						 Mcount_favorable(iter_strata,iter_d),
-						 Mcount_unfavorable(iter_strata,iter_d),
-						 Mcount_neutral(iter_strata,iter_d),
-						 Mcount_uninf(iter_strata,iter_d), 
-						 iIndex_neutralT, iIndex_neutralC, size_neutral,
-						 iIndex_uninfT, iIndex_uninfC, size_uninf,
-						 w, iIndex_w,
-						 keepComparison);
+        iScore = calcSubsetPairs_Continuous(ControlK.col(iter_d), TreatmentK.col(iter_d), threshold[iter_d],
+											correctionUninf,
+											Mcount_favorable(iter_strata,iter_d),
+											Mcount_unfavorable(iter_strata,iter_d),
+											Mcount_neutral(iter_strata,iter_d),
+											Mcount_uninf(iter_strata,iter_d),
+											iIndex_neutralC, iIndex_neutralT, size_neutral,
+											iIndex_uninfC, iIndex_uninfT, size_uninf,
+											w, iIndex_w,
+											neutralAsUninf, keepScore);
 	
       }
-      
+
       size_neutral = iIndex_neutralT.size(); // update the number of neutral pairs
       size_uninf = iIndex_uninfT.size(); // update the number of uninformative pairs
-      
+
+	  // Rcout << "update Wpairs" << endl;
       // **** update Wpairs
       if(D>iter_d+1){
         Wpairs.resize(size_neutral+size_uninf,iter_dTTE); // update the size of Wpairs
@@ -297,7 +310,7 @@ List GPC_cpp(const arma::mat& Treatment,
         w.resize(size_neutral+size_uninf); // update the size of w
         w.fill(1.0);
         
-        if((methodTTE>0 || correctionTTE) && iter_dTTE>0){
+        if((methodTTE>0 || correctionUninf>0) && iter_dTTE>0){
           tempo_index=iIndex_w; // store the position of the remaining pairs in the previous Wpairs (i.e. Wpairs_sauve)
           for(size_t iter_pair=0; iter_pair<tempo_index.size(); iter_pair++){
             
@@ -318,35 +331,28 @@ List GPC_cpp(const arma::mat& Treatment,
         }
       }
 
-      // **** update all Comparisons
-      if(keepComparison){
-	iNpairs = iComparison.n_rows;
+      // **** update all Scores
+	  // Rcout << "update Scores" << endl;
+	if(keepScore){
+	iNpairs = iScore.n_rows;
 	iMat.resize(iNpairs,3);
 
 	// add original index
 	for(int iPair=0 ; iPair < iNpairs ; iPair ++){
 	  iMat.row(iPair) = rowvec({(double)iter_strata,
-		(double)index_strataT(iComparison(iPair,0)),
-		(double)index_strataC(iComparison(iPair,1))});
+				    (double)index_strataC(iScore(iPair,0)),
+				    (double)index_strataT(iScore(iPair,1))});
 	}
      
 	// merge with current table and store
 	if(iter_strata==0){
-	  lsComp[iter_d] = arma::join_rows(iMat,iComparison);
+	  lsScore[iter_d] = arma::join_rows(iMat,iScore);
 	}else{
-	  lsComp[iter_d] = arma::join_cols(lsComp[iter_d], arma::join_rows(iMat,iComparison));
+	  lsScore[iter_d] = arma::join_cols(lsScore[iter_d], arma::join_rows(iMat,iScore));
 	}
       }
     } // end endpoint
 
-    // **** store index of the uniformative and neutral pairs
-    if(returnIndex==true){ // store the neutral and the uninformative pairs 
-      index_neutralT.insert(index_neutralT.end(), iIndex_neutralT.begin(), iIndex_neutralT.end()); // insert the neutral pairs of the treatment arm after those already founded
-      index_neutralC.insert(index_neutralC.end(), iIndex_neutralC.begin(), iIndex_neutralC.end()); // insert the neutral pairs of the control arm after those already founded
-      index_uninfT.insert(index_uninfT.end(), iIndex_uninfT.begin(), iIndex_uninfT.end());
-      index_uninfC.insert(index_uninfC.end(), iIndex_uninfC.begin(), iIndex_uninfC.end());    
-    }
-    
   }
   
   // ** proportion in favor of treatment 
@@ -358,32 +364,18 @@ List GPC_cpp(const arma::mat& Treatment,
                 D, n_strata, n_pairs);
 
   // ** export
-  if(returnIndex==true){
-    
-    return(List::create(
-			Named("count_favorable")  = Mcount_favorable,
-			Named("count_unfavorable")  = Mcount_unfavorable,
-			Named("count_neutral")  = Mcount_neutral,           
-			Named("count_uninf")  = Mcount_uninf,           
-			Named("delta_netChance")  = delta_netChance,
-			Named("delta_winRatio")  = delta_winRatio,
-			Named("Delta_netChance")  = Delta_netChance,
-			Named("Delta_winRatio")  = Delta_winRatio,
-			Named("index_neutralT")  = index_neutralT,
-			Named("index_neutralC")  = index_neutralC,
-			Named("index_uninfT")  = index_uninfT,
-			Named("index_uninfC")  = index_uninfC,
-			Named("n_pairs")  = n_pairs,
-			Named("tableComparison")  = lsComp
-			));
-  }else{
-    return(List::create(
-			Named("delta_netChance")  = delta_netChance,
-			Named("delta_winRatio")  = delta_winRatio,
-			Named("Delta_netChance")  = Delta_netChance,
-			Named("Delta_winRatio")  = Delta_winRatio
-			));
-  }                   
+  return(List::create(
+		      Named("count_favorable")  = Mcount_favorable,
+		      Named("count_unfavorable")  = Mcount_unfavorable,
+		      Named("count_neutral")  = Mcount_neutral,           
+		      Named("count_uninf")  = Mcount_uninf,           
+		      Named("delta_netChance")  = delta_netChance,
+		      Named("delta_winRatio")  = delta_winRatio,
+		      Named("Delta_netChance")  = Delta_netChance,
+		      Named("Delta_winRatio")  = Delta_winRatio,
+		      Named("n_pairs")  = n_pairs,
+		      Named("tableScore")  = lsScore
+		      ));
   
 }
 
