@@ -3,9 +3,9 @@
 ## Author: Brice Ozenne
 ## Created: dec 22 2017 (18:37) 
 ## Version: 
-## Last-Updated: apr 30 2018 (17:23) 
+## Last-Updated: sep 10 2018 (10:50) 
 ##           By: Brice Ozenne
-##     Update #: 16
+##     Update #: 21
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -23,7 +23,7 @@ context("Check the function initializing the thresholds")
 
 ## * settings
 BuyseTest.options(check = TRUE,
-                  keep.comparison = TRUE,
+                  keep.pairScore = TRUE,
                   method.inference = "none",
                   trace = 0)
 
@@ -43,7 +43,25 @@ test_that("Only accept NA or 1/2 for binary outcomes", {
                            method.inference = "none", trace = 0))
 })
 
-## * Continuous/TTE outcomes
+## * continuous outcomes
+
+test_that("Reject non-decreasing thresholds", {
+
+    expect_error(BuyseTest(Treatment ~ cont(score, threshold = 1) + cont(score, threshold = 2),
+                      data = dt,
+                      method.inference = "none", trace = 0))
+
+})
+
+test_that("convert 0 to 1e-12 - threshold",{
+    test <- BuyseTest(Treatment ~ cont(score, threshold = 1) + cont(score),
+                      data = dt,
+                      method.inference = "none", trace = 0)
+
+    expect_equal(test@threshold, c(1,1e-12))    
+})
+
+## * time to event outcomes
 
 test_that("Reject non-decreasing thresholds", {
 
@@ -66,5 +84,6 @@ test_that("convert 0 to 1e-12 - threshold",{
     expect_equal(test@threshold, c(1,1e-12))    
 })
 
+
 ##----------------------------------------------------------------------
 ### test-initThreshold.R ends here
